@@ -89,7 +89,7 @@ gnome_print_encode_rlc_wcs (gint size)
  * 
  * Return Value: size of the encodeed buffer
  **/
-#define _GNOME_PRINT_MAX_RUN_LENGTH_SIZE 256 /* Usefull for testing purposes */
+#define _GNOME_PRINT_MAX_RUN_LENGTH_SIZE 256 /* Useful for testing purposes */
 
 int
 gnome_print_encode_rlc (const guchar *in, guchar *out, gint in_size)
