@@ -27,6 +27,7 @@
 #include <config.h>
 #include <glib.h>
 #include <libgnomeprint/gnome-print-i18n.h>
+#include <libgnomeprint/gnome-print-path.h>
 
 char *
 libgnomeprint_gettext (const char *msgid)
@@ -34,7 +35,7 @@ libgnomeprint_gettext (const char *msgid)
 	static gboolean initialized = FALSE;
 
 	if (!initialized) {
-		bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
+		bindtextdomain (GETTEXT_PACKAGE, gnome_print_locale_dir);
 		bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 		initialized = TRUE;
 	}        
