@@ -25,7 +25,10 @@
 
 
 
-#include <popt.h>
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+#include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
 #include <libgnomeprint/gnome-print.h>
@@ -38,6 +41,9 @@ typedef enum {
 	BACKEND_META,
 #ifdef ENABLE_SVG
 	BACKEND_SVG,
+#endif
+#ifdef HAVE_GDI
+	BACKEND_GDI,
 #endif
 	BACKEND_UNKNOWN
 } BackendType;
@@ -46,25 +52,24 @@ static gchar *sequence_str = NULL;
 static gchar *backend_str = NULL;
 static gchar *replay_str = NULL;
 static gchar *output_str = NULL;
+static gchar **args = NULL;
 gboolean debug = FALSE;
 
-extern struct poptOption poptHelpOptions[];
-/* Only const exprs in initializer, and compliant compilers needn't choke */
-
-static struct poptOption options[] = {
-	{ "backend",   '\0', POPT_ARG_STRING, &backend_str, 0,
-	  "Backend to genereate",          "ps,pdf,meta"},
-	{ "sequence", '\0', POPT_ARG_STRING, &sequence_str,   0,
-	  "Sequence number of drawing commands, where nn is the sequence number", "nn, error_nn"},
-	{ "replay",   '\0', POPT_ARG_STRING, &replay_str,   0,
+static const GOptionEntry options[] = {
+	{ "backend",   '\0', 0, G_OPTION_ARG_STRING, &backend_str,
+	  "Backend to generate",          "ps,pdf,meta"},
+	{ "sequence", '\0', 0, G_OPTION_ARG_STRING, &sequence_str,
+	  "Sequence number of drawing commands, where nn is the sequence number", "nn,error_nn"},
+	{ "replay",   '\0', 0, G_OPTION_ARG_FILENAME, &replay_str,
 	  "Replay a metafile rather than using an internal sequence", "metafile"},
-	{ "debug",    '\0', POPT_ARG_NONE, &debug, 0,
+	{ "debug",    '\0', 0, G_OPTION_ARG_NONE, &debug,
 	  "Print debugging output",          NULL},
-	POPT_AUTOHELP
+	{ G_OPTION_REMAINING, '\0', 0, G_OPTION_ARG_FILENAME_ARRAY, &args,
+	  NULL,	NULL},
 	{ NULL }
 };
 
-static void parse_command_line (int argc, const char ** argv, BackendType *backend,
+static void parse_command_line (gint *argc, gchar *** argv, BackendType *backend,
 				gint *sequence, gchar **output, gchar **metafile);
 
 static void
@@ -483,7 +488,7 @@ my_replay (GnomePrintContext *gpc, const gchar *metafile)
 }
 
 int
-main (int argc, const char * argv[])
+main (int argc, char * argv[])
 
 {
 	GnomePrintContext *gpc;
@@ -501,7 +506,7 @@ main (int argc, const char * argv[])
 	const guchar *data;
 	int len;
 	
-	parse_command_line (argc, argv, &backend, &sequence, &output, &metafile);
+	parse_command_line (&argc, &argv, &backend, &sequence, &output, &metafile);
 
 	g_type_init ();
 	
@@ -553,6 +558,14 @@ main (int argc, const char * argv[])
 		if (!gnome_print_config_set (config, "Settings.Engine.Backend.Driver", "gnome-print-svg"))
 			my_error ("gnome_print_config_set Printer-SVG");
 		break;
+#endif
+#ifdef HAVE_GDI
+	case BACKEND_GDI:
+		if (!gnome_print_config_set (config, "Settings.Engine.Backend.Driver", "gnome-print-gdi"))
+			/* my_error ("gnome_print_config_set Printer-GDI");
+			   set_value may return FALSE when the Driver is already gnome-print-gdi, in this
+			   case it's not an error. */;
+		break;
 #endif
 	case BACKEND_UNKNOWN:
 	default:
@@ -599,6 +612,9 @@ usage (gchar *error)
 		 "         -pdf\n"
 #ifdef ENABLE_SVG
 		 "         -svg\n"
+#endif
+#ifdef HAVE_GDI
+		 "         -gdi\n"
 #endif
 		 "         -meta\n\n"
 		 "    Valid drawing sequences are: 0 thru 999 fixme\n"
@@ -607,14 +623,19 @@ usage (gchar *error)
 }
 
 static void
-parse_command_line (int argc, const char ** argv, BackendType *backend,
+parse_command_line (gint *argc, gchar *** argv, BackendType *backend,
 		    gint *sequence, gchar **output, gchar **metafile)
 {
-	poptContext popt;
-	const gchar **args;
+	GOptionContext *goption_context;
+	GError *error = NULL;
 
-	popt = poptGetContext ("generate", argc, argv, options, 0);
-	poptGetNextOpt (popt);
+	goption_context = g_option_context_new ("OUTPUT_FILE");
+	g_option_context_add_main_entries (goption_context, options, NULL);
+	g_option_context_parse (goption_context, argc, argv, &error);
+	g_option_context_free (goption_context);
+
+	if (error != NULL)
+		usage(error->message);
 
 	if (debug)
 		g_print ("Backend strings is: %s\n", backend_str);
@@ -628,6 +649,10 @@ parse_command_line (int argc, const char ** argv, BackendType *backend,
 #ifdef ENABLE_SVG
 	else if (!strcmp ("svg", backend_str))
 		*backend = BACKEND_SVG;
+#endif
+#ifdef HAVE_GDI
+	else if (!strcmp ("gdi", backend_str))
+		*backend = BACKEND_GDI;
 #endif
 	else if (!strcmp ("meta", backend_str))
 		*backend = BACKEND_META;
@@ -669,7 +694,6 @@ parse_command_line (int argc, const char ** argv, BackendType *backend,
 end_parse_command_line:
 	/* Get output filename */
 	output_str = NULL;
-	args = poptGetArgs (popt);
 
 	if (!args || !args[0]) {
 		usage ("Output file not specified");
@@ -677,7 +701,5 @@ end_parse_command_line:
 	
 	*output = g_strdup (args [0]);
 	output_str = g_strdup (args [0]);
-
-	poptFreeContext (popt);
 }
 
